@@ -166,7 +166,7 @@ class BaseProvider:
         if isinstance(fields, str):
             fields = [fields, ]
         if fields is None:
-            _, _, others, _, _ = DatasetD.dataset_info(dataset)
+            _, _, others, _, _, _ = DatasetD.dataset_info(dataset)
             fields = list(others.keys())
         fields = list(fields)
         return DatasetD.datasets(instruments, fields, start_time, end_time, dataset)
@@ -182,7 +182,7 @@ class BaseProvider:
         if isinstance(fields, str):
             fields = [fields, ]
         if fields is None:
-            _, _, others, _, _ = DatasetD.dataset_info(dataset)
+            _, _, others, _, _, _ = DatasetD.dataset_info(dataset)
             fields = list(others.keys())
         fields = list(fields)
         return DatasetD.datasets_fl(filt, fields, dataset, **kwargs)
@@ -273,27 +273,27 @@ class CalendarProvider:
             return predt
         else:
             if shifts > 0:
-                index = self.cal_loc(dt, "b", freq)
+                index = self.cal_loc(dt, "f", freq)
                 if calendar_index.get(dt) is None:
                     shifts -= 1
             else:
-                index = self.cal_loc(dt, "f", freq)
+                index = self.cal_loc(dt, "b", freq)
                 if calendar_index.get(dt) is None:
                     shifts = min(0, shifts + 1)
         return calendar[index + shifts]
 
     def cal_delta(self, sdt, edt, freq: str = "Tday"):
         """return diff between dates"""
-        si = self.cal_loc(sdt, "f", freq)
-        ei = self.cal_loc(edt, "f", freq)
+        si = self.cal_loc(sdt, "b", freq)
+        ei = self.cal_loc(edt, "b", freq)
         return ei - si
 
-    def near_dts(self, dt, mode: str = "f", freq: str="Tday"):
+    def near_dts(self, dt, mode: str = "b", freq: str="Tday"):
         _calendar, _calendar_index = self._get_calendar(freq=freq)
         locations = self.cal_loc(dt, mode, freq)
         return _calendar[locations]
 
-    def cal_loc(self, dt: Iterable, mode: str = "f", freq: str = "Tday"):
+    def cal_loc(self, dt: Iterable, mode: str = "b", freq: str = "Tday"):
         """
         :param dt: int or iterable
         :param mode: f for forward or b for backward if dt not in calendar index
@@ -303,10 +303,10 @@ class CalendarProvider:
         calendar, calendar_index = self._get_calendar(freq=freq)
         if isinstance(dt, Iterable):
             index = np.array([self.cal_loc(dt_i, mode, freq) for dt_i in dt])
-        elif isinstance(dt, int):
+        elif isinstance(dt, (int, np.int)):
             if dt not in calendar_index:
                 try:
-                    if mode == "f":
+                    if mode == "b":
                         dt = calendar[bisect_right(calendar, dt) - 1]
                     else:
                         dt = calendar[bisect_left(calendar, dt)]
@@ -621,7 +621,7 @@ class DatasetProvider(BaseDataProvider):
         # One process for one task, so that the memory will be freed quicker.
         normalize_column_names = DatasetD.normalize_cache_fields(column_names)
         config_path = os.path.join(fpath, "config.json")
-        code_flt, time_flt, _, is_annrepo, format_ = DatasetD.read_config(config_path)
+        code_flt, time_flt, _, is_annrepo, format_, _ = DatasetD.read_config(config_path)
         primary_keys = [code_flt, time_flt]  # 插入primary key
         if is_annrepo:
             primary_keys += ["report_period"]
@@ -660,7 +660,7 @@ class DatasetProvider(BaseDataProvider):
         """
         # One process for one task, so that the memory will be freed quicker.
         config_path = os.path.join(fpath, "config.json")
-        code_flt, time_flt, _, is_annrepo, format_ = DatasetD.read_config(config_path)
+        code_flt, time_flt, _, is_annrepo, format_, _ = DatasetD.read_config(config_path)
         primary_keys = [code_flt, time_flt]  # 插入primary key
         if is_annrepo:
             primary_keys += ["report_period"]
@@ -692,9 +692,10 @@ class DatasetProvider(BaseDataProvider):
             code_flt = json_cfg["code_flt"]
             time_flt = json_cfg["time_flt"]
             others = json_cfg["others"]
+            label_match = json_cfg["label_match"]
             is_annrepo = json_cfg["is_annrepo"]
             format_ = json_cfg.get("format", "feather")
-        return code_flt, time_flt, others, is_annrepo, format_
+        return code_flt, time_flt, others, is_annrepo, format_, label_match
 
 
 def list_features(freq="*"):
